@@ -16,7 +16,7 @@ use crate::TransferAdmin;
 /// --------------------------------
 
 impl<'info> Validate<'info> for NewWrapper<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         assert_keys_eq!(
             self.token_mint.mint_authority.unwrap(),
             self.mint_wrapper,
@@ -32,14 +32,14 @@ impl<'info> Validate<'info> for NewWrapper<'info> {
 }
 
 impl<'info> Validate<'info> for NewMinter<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.auth.validate()?;
         Ok(())
     }
 }
 
 impl<'info> Validate<'info> for MinterUpdate<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.auth.validate()?;
         assert_keys_eq!(
             self.minter.mint_wrapper,
@@ -51,7 +51,7 @@ impl<'info> Validate<'info> for MinterUpdate<'info> {
 }
 
 impl<'info> Validate<'info> for TransferAdmin<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(self.admin.is_signer, Unauthorized);
         assert_keys_eq!(self.admin, self.mint_wrapper.admin, "admin");
         assert_keys_neq!(self.next_admin, self.mint_wrapper.admin, "next_admin");
@@ -61,7 +61,7 @@ impl<'info> Validate<'info> for TransferAdmin<'info> {
 }
 
 impl<'info> Validate<'info> for AcceptAdmin<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(self.pending_admin.is_signer, Unauthorized);
         assert_keys_eq!(
             self.pending_admin,
@@ -73,7 +73,7 @@ impl<'info> Validate<'info> for AcceptAdmin<'info> {
 }
 
 impl<'info> Validate<'info> for PerformMint<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(
             self.mint_wrapper.to_account_info().is_writable,
             Unauthorized
@@ -99,7 +99,7 @@ impl<'info> Validate<'info> for PerformMint<'info> {
 /// --------------------------------
 
 impl<'info> Validate<'info> for OnlyAdmin<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(self.admin.is_signer, Unauthorized);
         assert_keys_eq!(self.admin, self.mint_wrapper.admin, "admin");
         Ok(())
